==> qtjambi-uic-5.15.17-sources.jar: io/qt/uic/ui4/DomPalette.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomPalette</code></p>
 */
public class DomPalette extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomPalette::<wbr>DomPalette()</code></p>
     */
    public DomPalette(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPalette instance);
    
    /**
     * <p>See <code>DomPalette::<wbr>clearElementActive()</code></p>
     */
    @QtUninvokable
    public final void clearElementActive(){
        clearElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementActive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>clearElementDisabled()</code></p>
     */
    @QtUninvokable
    public final void clearElementDisabled(){
        clearElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementDisabled_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>clearElementInactive()</code></p>
     */
    @QtUninvokable
    public final void clearElementInactive(){
        clearElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementInactive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>elementActive()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementActive(){
        return elementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementActive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>elementDisabled()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementDisabled(){
        return elementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementDisabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>elementInactive()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementInactive(){
        return elementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementInactive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>hasElementActive()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementActive(){
        return hasElementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementActive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>hasElementDisabled()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementDisabled(){
        return hasElementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementDisabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>hasElementInactive()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementInactive(){
        return hasElementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementInactive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomPalette::<wbr>setElementActive(DomColorGroup*)</code></p>
     */
    @QtUninvokable
    public final void setElementActive(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementActive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementActive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomPalette::<wbr>setElementDisabled(DomColorGroup*)</code></p>
     */
    @QtUninvokable
    public final void setElementDisabled(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementDisabled_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementDisabled_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomPalette::<wbr>setElementInactive(DomColorGroup*)</code></p>
     */
    @QtUninvokable
    public final void setElementInactive(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementInactive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementInactive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomPalette::<wbr>takeElementActive()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementActive(){
        return takeElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementActive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>takeElementDisabled()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementDisabled(){
        return takeElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementDisabled_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>takeElementInactive()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementInactive(){
        return takeElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementInactive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomPalette(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomPalette.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomPalette</code></p>
 */
public class DomPalette extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomPalette::<wbr/>DomPalette()</code></p>
     */
    public DomPalette(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPalette instance);
    
    /**
     * <p>See <code>DomPalette::<wbr/>clearElementActive()</code></p>
     */
    @QtUninvokable
    public final void clearElementActive(){
        clearElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementActive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>clearElementDisabled()</code></p>
     */
    @QtUninvokable
    public final void clearElementDisabled(){
        clearElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementDisabled_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>clearElementInactive()</code></p>
     */
    @QtUninvokable
    public final void clearElementInactive(){
        clearElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementInactive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>elementActive()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementActive(){
        return elementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementActive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>elementDisabled()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementDisabled(){
        return elementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementDisabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>elementInactive()const</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementInactive(){
        return elementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementInactive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>hasElementActive()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementActive(){
        return hasElementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementActive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>hasElementDisabled()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementDisabled(){
        return hasElementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementDisabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>hasElementInactive()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementInactive(){
        return hasElementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementInactive_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomPalette::<wbr/>setElementActive(DomColorGroup*)</code></p>
     */
    @QtUninvokable
    public final void setElementActive(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementActive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementActive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomPalette::<wbr/>setElementDisabled(DomColorGroup*)</code></p>
     */
    @QtUninvokable
    public final void setElementDisabled(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementDisabled_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementDisabled_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomPalette::<wbr/>setElementInactive(DomColorGroup*)</code></p>
     */
    @QtUninvokable
    public final void setElementInactive(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementInactive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementInactive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    /**
     * <p>See <code>DomPalette::<wbr/>takeElementActive()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementActive(){
        return takeElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementActive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>takeElementDisabled()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementDisabled(){
        return takeElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementDisabled_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>takeElementInactive()</code></p>
     */
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementInactive(){
        return takeElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementInactive_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomPalette::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomPalette(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}
